#!/usr/bin/env python
import os
import hashlib
import json
import io

from six.moves.urllib import request

from dateutil.zoneinfo import rebuild

METADATA_FILE = "zonefile_metadata.json"


def main():
    with io.open(METADATA_FILE, 'r') as f:
        metadata = json.load(f)

    if not os.path.isfile(metadata['tzdata_file']):
        print("Downloading tz file from iana")
        request.urlretrieve(os.path.join(metadata['releases_url'],
                                         metadata['tzdata_file']),
                            metadata['tzdata_file'])
    with open(metadata['tzdata_file'], 'rb') as tzfile:
        sha_hasher = hashlib.sha512()
        sha_hasher.update(tzfile.read())
        sha_512_file = sha_hasher.hexdigest()
        assert metadata['tzdata_file_sha512'] == sha_512_file, "SHA failed for"
    print("Updating timezone information...")
    rebuild(metadata['tzdata_file'], zonegroups=metadata['zonegroups'])
    print("Done.")

if __name__ == "__main__":
    main()



#!/usr/bin/python
from os.path import isfile
import codecs
import os
import re

from setuptools import setup


if isfile("MANIFEST"):
    os.unlink("MANIFEST")


TOPDIR = os.path.dirname(__file__) or "."
VERSION = re.search('__version__ = "([^"]+)"',
                    codecs.open(TOPDIR + "/dateutil/__init__.py",
                                encoding='utf-8').read()).group(1)


setup(name="python-dateutil",
      version=VERSION,
      description="Extensions to the standard Python datetime module",
      author="Yaron de Leeuw",
      author_email="me@jarondl.net",
      url="https://dateutil.readthedocs.org",
      license="Simplified BSD",
      long_description="""
The dateutil module provides powerful extensions to the
datetime module available in the Python standard library.
""",
      packages=["dateutil", "dateutil.zoneinfo"],
      package_data={"dateutil.zoneinfo": ["dateutil-zoneinfo.tar.gz"]},
      zip_safe=True,
      requires=["six"],
      install_requires=["six >=1.5"],  # XXX fix when packaging is sane again
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: BSD License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.2',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Topic :: Software Development :: Libraries',
      ],
      test_suite="dateutil.test.test"
      )
